@@ -36,7 +36,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
     opened=None
 
     def tables(self, *args, **kw):
-        self._begin()
         c = self.conn.cursor()
 
         if with_system_flag:
@@ -52,11 +51,9 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
                 from rdb$relations where rdb$flags=1 
                 order by rdb$relation_name''')
         rows = fetchallmap(c)
-        self._finish()
         return rows
 
     def columns(self, table_name):
-        self._begin()
         c = self.conn.cursor()
 
         r=c.execute('''select A.rdb$field_name NAME, 
@@ -72,11 +69,9 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
 
         rows=fetchallmap(c)
 
-        self._finish()
         return rows
 
     def constraints(self, table_name):
-        self._begin()
         c = self.conn.cursor()
 
         r=c.execute('''select 
@@ -113,7 +108,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
 
             d[row['INDEX_ID']]['FIELD_NAME'].append(row['FIELD_NAME'])
 
-        self._finish()
 
         return d
 
@@ -132,7 +126,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
         return (index_name, string.strip(rows[0][0]), d)  #index,table,[fields]
 
     def triggers(self, table_name):
-        self._begin()
         c = self.conn.cursor()
 
         if with_system_flag:
@@ -158,11 +151,9 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
                     order by rdb$trigger_sequence''' % table_name)
 
         rows = fetchallmap(c)
-        self._finish()
         return rows
 
     def check_constraints(self, table_name):
-        self._begin()
         c = self.conn.cursor()
 
         r=c.execute('''select 
@@ -182,12 +173,10 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
             d[row[0]] = {'CHECK_NAME': string.strip(row[0]),
                         'CHECK_SOURCE': string.strip(row[1])}
 
-        self._finish()
 
         return d
 
     def generators(self):
-        self._begin()
         c = self.conn.cursor()
 
         if with_system_flag:
@@ -208,11 +197,9 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
                     'SYSTEM_FLAG': gen[1],
                     'GENERATOR_COUNT': count})
 
-        self._finish()
         return r
 
     def procedures(self):
-        self._begin()
         c = self.conn.cursor()
 
         c.execute('''select rdb$procedure_name, rdb$procedure_source 
@@ -249,11 +236,11 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
                     'IN_PARAMS': in_params,
                     'OUT_PARAMS':out_params})
 
-        self._finish()
         return r
 
     def open(self):
         self.conn = firebirdsql.connect(**self.conn_args)
+        self.conn.set_autocommit(True)
         self.opened=DateTime()
 
     def close(self):
@@ -271,7 +258,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
         self.open()
 
     def query(self,query_string, max_rows=9999999):
-        self._begin()
         c = self.conn.cursor()
 
         queries=filter(None, map(string.strip,string.split(query_string, '\0')))
@@ -284,7 +270,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
             if d is None: continue
             if desc is None: desc=d
             elif d != desc:
-                self._abort()
                 raise QueryError, (
                     'Multiple incompatible selects in '
                     'multiple sql-statement query'
@@ -295,7 +280,6 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
                 if r:
                     result += r
 
-        self._finish()
 
         if desc is None:
             return (), ()
@@ -317,11 +301,3 @@ class DB(Shared.DC.ZRDB.THUNK.THUNKED_TM):
 
         return items, result
 
-    def _begin(self):
-        self.conn.begin()
-
-    def _finish(self):
-        self.conn.commit()
-
-    def _abort(self):
-        self.conn.rollback()
